@@ -2,7 +2,7 @@
 
 mkdir /usr/share/gnome-sshman
 cp libs/gssh-main.glade* /usr/share/gnome-sshman
-cp libs/gnomesshman.py /usr/share/gnome-sshman
+cp libs/*.py /usr/share/gnome-sshman
 cp libs/*png /usr/share/gnome-sshman
 cp bin/gnome-sshman /usr/bin
 cp -prf i18n/* /usr/share/locale/
